import Cell from "./Cell"
import { chakra, useMultiStyleConfig } from "~/system"
import type { Column } from "../types"

interface Props<Data> {
  data: Data
  columns: Column<Data>[]
  index: number
  onRowClick?: (row: Data) => void
}

function Row<Data extends {}>({ columns, data, index, onRowClick }: Props<Data>) {
  const styles = useMultiStyleConfig("Table", {})

  return (
    <chakra.div
      __css={styles.tr}
      role="row"
      aria-rowindex={index + 1}
      onClick={onRowClick ? () => onRowClick(data) : undefined}
    >
      {columns.map((column) => (
        <Cell key={column.key} data={data} column={column} />
      ))}
    </chakra.div>
  )
}

export default Row
